@@ -1,7 +1,7 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "lfe-mode" "2.2.0"
+(define-package "lfe-mode" "20250702.1243"
   "Lisp Flavoured Erlang mode."
   ()
   :url "https://github.com/rvirding/lfe"
-  :commit "716a6959e4f02d200273fdabb7e1900e0a4c6a8e"
-  :revdesc "716a6959e4f0")
+  :commit "ebd7d221c52b6bf8c47c9e4f7daf15b3dee4d3fa"
+  :revdesc "ebd7d221c52b")
